@@ -24,7 +24,7 @@
 #define OPTIONS_DIALOG_H
 
 #include <libguile.h>
-#include "option-util.h"
+#include "app-utils/option-util.h"
 #include <gtk/gtk.h>
 
 /** A simple wrapper that casts the gpointer result of
@@ -35,15 +35,18 @@ typedef struct gnc_option_win GNCOptionWin;
 
 typedef void (* GNCOptionWinCallback)(GNCOptionWin *, gpointer data);
 
+GNCOptionWin * gnc_options_dialog_new_modal(gboolean modal, gchar *title);
 GNCOptionWin * gnc_options_dialog_new(gchar *title);
 GNCOptionWin * gnc_options_dialog_new_w_dialog(gchar *title, GtkWidget *dialog);
 void gnc_options_dialog_destroy(GNCOptionWin * win);
 void gnc_options_register_stocks (void);
 
 GtkWidget * gnc_options_dialog_widget(GNCOptionWin * win);
+GtkWidget * gnc_options_page_list(GNCOptionWin * win);
 GtkWidget * gnc_options_dialog_notebook(GNCOptionWin * win);
 
 void gnc_options_dialog_changed (GNCOptionWin *win);
+
 void gnc_option_changed_widget_cb(GtkWidget *widget, GNCOption *option);
 void gnc_option_changed_option_cb(GtkWidget *dummy, GNCOption *option);
 
@@ -63,6 +66,10 @@ void gnc_options_dialog_set_global_help_cb(GNCOptionWinCallback thunk,
 void gnc_options_dialog_build_contents(GNCOptionWin *win,
                                        GNCOptionDB  *odb);
 
+void gnc_options_dialog_build_contents_full(GNCOptionWin *win,
+                                            GNCOptionDB  *odb,
+                                            gboolean show_dialog);
+
 /* Both apply_cb and close_cb should be scheme functions with 0 arguments.
  * References to these functions will be held until the close_cb is called
  */
@@ -75,28 +82,27 @@ void gnc_options_dialog_set_scm_callbacks (GNCOptionWin *win,
 
 /* Function to set the UI widget based upon the option */
 typedef GtkWidget *
-(*GNCOptionUISetWidget)	(GNCOption *option, GtkBox *page_box,
-                         GtkTooltips *tooltips,
+(*GNCOptionUISetWidget) (GNCOption *option, GtkBox *page_box,
                          char *name, char *documentation,
                          /* Return values */
                          GtkWidget **enclosing, gboolean *packed);
 
 /* Function to set the UI Value for a particular option */
 typedef gboolean
-(*GNCOptionUISetValue)	(GNCOption *option, gboolean use_default,
+(*GNCOptionUISetValue)  (GNCOption *option, gboolean use_default,
                          GtkWidget *widget, SCM value);
 
 /* Function to get the UI Value for a particular option */
 typedef SCM
-(*GNCOptionUIGetValue)	(GNCOption *option, GtkWidget *widget);
+(*GNCOptionUIGetValue)  (GNCOption *option, GtkWidget *widget);
 
 
 typedef struct gnc_option_def
 {
-    const char *		option_name;
-    GNCOptionUISetWidget	set_widget;
-    GNCOptionUISetValue	set_value;
-    GNCOptionUIGetValue	get_value;
+    const char *         option_name;
+    GNCOptionUISetWidget set_widget;
+    GNCOptionUISetValue  set_value;
+    GNCOptionUIGetValue  get_value;
 } GNCOptionDef_t;
 
 
